==> pokox_1.0.0.tar.gz: pokox/story/PlainSession.class.php <==
<?php
/*
 * This file is part of the PokoX package.
 * Copyright (c) 2003 - 2005 Akira Kaze
 *
 * Character set is EUC-JP.
 *
 * For license information, please view the COPYRIGHT.txt file that was 
 * distributed with this source code. If the COPYRIGHT.txt file is missing, 
 * please visit the PokoX homepage: http://www.glamenv-septzen.net/
 *
 * $Id: PlainSession.class.php,v 1.3 2005/07/10 20:59:22 fenjin Exp $
 */

/**
 * <pre>
 * PlainSession ȡ꡼饹⥸塼
 *
 * åѤ뤬⤻Τޤޥ롼롣
 * åΥѥ᡼$POKOX_STORY_PARAMSХϢ󤫤
 *
 * $_POKOX["pokox.aci"] ̤ξ硢start()"*"˥åȤ롣
 * (̤ξǤäơץ¦ȼꤷƤ硢뤤
 *  Ǥ"*"åȤƤϾ񤭤ʤ)
 * </pre>
 *
 * @author Akira Kaze <feng-jing-gsyc-2s@glamenv-septzen.net>
 * @package PokoX
 * @since 1.0
 */
class PlainSession extends PokoXStory {

	function &PlainSession()
	{
	}

	function start(&$pokox)
	{
		global $POKOX_STORY_PARAMS;

		$lifetime = @$POKOX_STORY_PARAMS["session_lifetime"];
		$path = @$POKOX_STORY_PARAMS["session_path"];
		$domain = @$POKOX_STORY_PARAMS["session_domain"];
		$secure = @$POKOX_STORY_PARAMS["session_secure"];
		$name = @$POKOX_STORY_PARAMS["session_name"];

		session_set_cookie_params($lifetime, $path, $domain, $secure);
		if(isset($name) && $name != "") {
			session_name($name);
		}
		session_start();

		if(!isset($_SESSION["POKOX_SESSION_VARS"])) {
			$_SESSION["POKOX_SESSION_VARS"] = array();
		}
		$GLOBALS["_POKOX"] =& $_SESSION["POKOX_SESSION_VARS"];

		global $_POKOX;
		if(!isset($_POKOX["pokox_aci"]))
			$_POKOX["pokox_aci"] = "*";
	}
	
	function story(&$pokox)
	{
		if(isset($_GET[POKOX_STORY_KEY])) {
			$story = $_GET[POKOX_STORY_KEY];
		} else if(isset($_POST[POKOX_STORY_KEY])) {
			$story = $_POST[POKOX_STORY_KEY];
		} else {
			$story = "";
		}

		return $story;
	}
	
	function end(&$pokox)
	{
	}

}
	
?>

==> pokox_1.3.0.tar.gz: pokox/story/PlainSession.class.php <==
<?php
/*
 * This file is part of the PokoX package.
 * Copyright (c) 2003 - 2005 Akira Kaze
 *
 * Character set is EUC-JP.
 *
 * For license information, please view the COPYRIGHT.txt file that was 
 * distributed with this source code. If the COPYRIGHT.txt file is missing, 
 * please visit the PokoX homepage: http://www.glamenv-septzen.net/
 *
 * $Id: PlainSession.class.php,v 1.5 2005/08/11 09:01:05 fenjin Exp $
 */

/**
 * PlainSession ȡ꡼饹⥸塼
 *
 * <pre>
 * åѤ뤬⤻Τޤޥ롼롣
 * åΥѥ᡼$POKOX_STORY_PARAMSХϢ󤫤
 *
 * $_POKOX[POKOX_ACI_KEY] ̤ξ硢start()"*"˥åȤ롣
 * (̤ξǤäơץ¦ȼꤷƤ硢뤤
 *  Ǥ"*"åȤƤϾ񤭤ʤ)
 * </pre>
 *
 * @author Akira Kaze <feng-jing-gsyc-2s@glamenv-septzen.net>
 * @package PokoX
 * @since 1.0
 */
class PlainSession extends PokoXStory {

	function start(&$pokox)
	{
		global $POKOX_STORY_PARAMS;

		$lifetime = @$POKOX_STORY_PARAMS["session_lifetime"];
		$path = @$POKOX_STORY_PARAMS["session_path"];
		$domain = @$POKOX_STORY_PARAMS["session_domain"];
		$secure = @$POKOX_STORY_PARAMS["session_secure"];
		$name = @$POKOX_STORY_PARAMS["session_name"];

		session_set_cookie_params($lifetime, $path, $domain, $secure);
		if(isset($name) && $name != "") {
			session_name($name);
		}
		session_start();

		if(!isset($_SESSION["POKOX_SESSION_VARS"])) {
			$_SESSION["POKOX_SESSION_VARS"] = array();
		}
		$GLOBALS["_POKOX"] =& $_SESSION["POKOX_SESSION_VARS"];

		global $_POKOX;
		if(!isset($_POKOX["pokox_aci"]))
			$_POKOX["pokox_aci"] = "*";
	}
	
	function story(&$pokox)
	{
		if(isset($_GET[POKOX_STORY_KEY])) {
			$story = $_GET[POKOX_STORY_KEY];
		} else if(isset($_POST[POKOX_STORY_KEY])) {
			$story = $_POST[POKOX_STORY_KEY];
		} else {
			$story = "";
		}

		return $story;
	}
	
	function end(&$pokox)
	{
	}

}
	
?>
